//
//  BFAnalyzeFunc.swift
//  BFAnalyzeKit
//
//  Created by SanW on 2021/12/10.
//

import BFNetRequestKit
import UIKit

// MARK: 字典转字符串

public func bf_dictionaryToJsonString(_ dic: [String: Any]) -> String? {
    if !JSONSerialization.isValidJSONObject(dic) {
        return ""
    }
    guard let data = try? JSONSerialization.data(withJSONObject: dic, options: []) else {
        return ""
    }
    let str = String(data: data, encoding: String.Encoding.utf8)
    return str
}

/// 数组转为string
/// - Parameter array: <#array description#>
/// - Returns: <#description#>
public func bf_arrayToJsonString(_ array: [Any]) -> String {
    if !JSONSerialization.isValidJSONObject(array) {
        return ""
    }
    let data: NSData! = try? JSONSerialization.data(withJSONObject: array, options: []) as NSData?
    let JSONString = NSString(data: data as Data, encoding: String.Encoding.utf8.rawValue)
    return JSONString! as String
}

/// dns解析
/// - Parameter hostUrl: speed.piaoquantv.com /
/// - Returns: <#description#>
public func bf_parseDNS(hostUrl: String) -> [String: Any]? {
    let host: CFHost? = CFHostCreateWithName(nil, hostUrl as CFString).takeRetainedValue()
    let start = CFAbsoluteTimeGetCurrent()
    var success: DarwinBoolean = false
    var addressList: [String] = Array<String>.init()
    var addresses: NSArray?
    if CFHostStartInfoResolution(host!, .addresses, nil) {
        addresses = (CFHostGetAddressing(host!, &success)?.takeUnretainedValue())
    }
    if success == true {
        for case let theAddress as NSData in addresses! {
            var hostname = [CChar](repeating: 0, count: Int(NI_MAXHOST))
            if getnameinfo(theAddress.bytes.assumingMemoryBound(to: sockaddr.self), socklen_t(theAddress.length),
                           &hostname, socklen_t(hostname.count), nil, 0, NI_NUMERICHOST) == 0
            {
                let numAddress = String(cString: hostname)
                addressList.append("\(hostUrl)/\(numAddress)")
            }
        }
    }
    let end = CFAbsoluteTimeGetCurrent()
    let duration = end - start
    if addressList.count > 0 {
        return ["dnsResult": bf_arrayToJsonString(addressList), "duration": duration * 1000, "hostName": hostUrl, "networkType": SWNetRequest.networkStatusDescription()]
    } else {
        return nil
    }
}
